diff mbox

tags: Use $SRCARCH

Message ID 1266612308-2911-1-git-send-email-mmarek@suse.cz (mailing list archive)
State New, archived
Headers show

Commit Message

Michal Marek Feb. 19, 2010, 8:45 p.m. UTC
None
diff mbox

Patch

diff --git a/scripts/tags.sh b/scripts/tags.sh
index c122041..9f45953 100755
--- a/scripts/tags.sh
+++ b/scripts/tags.sh
@@ -5,7 +5,7 @@ 
 # mode may be any of: tags, TAGS, cscope
 #
 # Uses the following environment variables:
 # ARCH, SUBARCH, srctree, src, obj
 
 if [ "$KBUILD_VERBOSE" = "1" ]; then
 	set -x
@@ -70,7 +70,7 @@  find_sources()
 
 all_sources()
 {
-	find_arch_include_sources ${ARCH} '*.[chS]'
+	find_arch_include_sources ${SRCARCH} '*.[chS]'
 	if [ ! -z "$archinclude" ]; then
 		find_arch_include_sources $archinclude '*.[chS]'
 	fi
@@ -5,7 +5,7 @@ 
 #
 # Uses the following environment variables:
-# ARCH, SUBARCH, srctree, src, obj
+# ARCH, SUBARCH, SRCARCH, srctree, src, obj
 
 if [ "$KBUILD_VERBOSE" = "1" ]; then